Products.zms.zms.ZMS

Package Products :: Package zms :: Module zms :: Class ZMS |
[frames] | no frames]

# Class ZMS

                           zmscustom.ZMSCustom --+
                                                 |
                  _accessmanager.AccessManager --+
                                                 |
                              _builder.Builder --+
                                                 |
    _multilangmanager.MultiLanguageManager --+   |
                                             |   |
              _filtermanager.FilterManager --+   |
                                             |   |
                      _confmanager.ConfManager --+
                                                 |
                     _objattrs.ObjAttrsManager --+
                                                 |
              _zcatalogmanager.ZCatalogManager --+
                                                 |
                                                ZMS

Instance Methods
__init__(self) |
icon(self) |
initZMS(self, container, id, titlealt, title, lang, manage_lang, REQUEST) |
manage_addMediaDb(self, location, REQUEST=None, RESPONSE=None) |
zms_version(self) Try to obtain the version from package info if installed by pip otherwise read from version.txt and from svnversion |
getDocumentElement(self) |
getRootElement(self) |
getAbsoluteHome(self) |
getHome(self) |
getTrashcan(self) |
getNewId(self, id_prefix='e') |
getDCCoverage(self, REQUEST={}) |
getPortalMaster(self) |
getPortalClients(self) |
getParentNode(self) |
xmlOnStartElement(self, sTagName, dTagAttrs, oParentNode, oRoot) |
Inherited from `_confmanager.ConfManager`: `customize_manage_options`, `delConfProperty`, `getCatalogAdapter`, `getCharFormats`, `getConfFiles`, `getConfManager`, `getConfProperties`, `getConfPropertiesDefaults`, `getConfProperty`, `getConfXmlFile`, `getFormatManager`, `getLocale`, `getMediaDb`, `getMetaCmd`, `getMetaCmdDescription`, `getMetaCmdIds`, `getMetaCmds`, `getMetacmdManager`, `getMetaobj`, `getMetaobjAttr`, `getMetaobjAttrIdentifierId`, `getMetaobjAttrIds`, `getMetaobjAttrs`, `getMetaobjId`, `getMetaobjIds`, `getMetaobjManager`, `getMetaobjRevision`, `getPluginIds`, `getRepositoryManager`, `getReqProperty`, `getResourceFolders`, `getSequence`, `getStylesheet`, `getStylesheets`, `getTextFormat`, `getTextFormatDefault`, `getTextFormats`, `getThemes`, `getWfActivities`, `getWfActivitiesIds`, `getWfActivity`, `getWfTransition`, `getWfTransitions`, `getWorkflowManager`, `get_conf_properties`, `get_conf_property`, `importConf`, `importConfPackage`, `manage_customizeDesign`, `manage_customizeSystem`, `notifyMetaobjAttrAboutValue`, `setConfProperty`

Class Variables
| zms_build = `'134'`
| zms_patch = `'c'`
| meta_id = `"ZMS"`
| meta_type = `"ZMS"`
| __administratorPermissions__ = `'manage_customize', 'manage_cus`...``
| __authorPermissions__ = `'manage', 'manage_main', 'manage_main_`...``
| __userAdministratorPermissions__ = `'manage_users', 'manage_use`...``
| __ac_permissions__ = `'ZMS Administrator', __administratorPermi`...``
| dGlobalAttrs = `{'ZMS': {'obj_class': None}, 'ZMSCustom': {'obj`...``
| index_html = `PageTemplateFile('zpt/ZMS/index', globals())`
| f_index_html = `PageTemplateFile('zpt/ZMS/index', globals())`
| f_headDoctype = `PageTemplateFile('zpt/ZMS/f_headdoctype', glob`...``
| f_headTitle = `PageTemplateFile('zpt/ZMS/f_headtitle', globals())`
| f_headMeta_DC = `PageTemplateFile('zpt/ZMS/f_headmeta_dc', glob`...``
| f_headMeta_Locale = `PageTemplateFile('zpt/ZMS/f_headmeta_local`...``
| f_standard_html_header = `PageTemplateFile('zpt/ZMS/f_standard_`...``
| f_standard_html_footer = `PageTemplateFile('zpt/ZMS/f_standard_`...``
| headScript = `PageTemplateFile('zpt/ZMS/headscript', globals())`
| headMeta = `PageTemplateFile('zpt/ZMS/headmeta', globals())`
| headCStyleSheet = `PageTemplateFile('zpt/ZMS/headcstylesheet', `...``
| headCSS = `PageTemplateFile('zpt/ZMS/headcstylesheet', globals())`
| enumManager = `_enummanager.EnumManager()` ############################################################################ ### ### Constructor ### ############################################################################
Inherited from `_confmanager.ConfManager`: `customize_manage_options__roles__`, `manage_customize`, `manage_customizeDesignForm`, `manage_customizeFilterForm`, `manage_customizeLanguagesForm`, `security`

Instance Variables
Inherited from `_confmanager.ConfManager`: `__attr_conf_dict__`

Method Details

### zms_version(self) |
Try to obtain the version from package info if installed by pip otherwise read from version.txt and from svnversion installed by pip from PyPI (revision 'XXXX' in version.txt - package info of official releases does not contain revision) installed by pip from ZMSLabs w/ info by svn (revision 'svn-rXXXX' in package info due to setup.cfg) installed by pip from TAR-Ball w/o info by svn (revision 'XXXX' in version.txt due to nightly build - 'svn0' in package info due to setup.cfg) deployed to instance/Products (revision 'XXXX' in version.txt, maybe installed but unused package) checked out to instance/Products as working copy from svn (revision 'REV' in version.txt, maybe installed but unused package)

Class Variable Details

  ### __administratorPermissions__ Value:
      'manage_customize', 'manage_customizeSystem', 'manage_changeLanguages'
      , 'manage_customizeLanguagesForm', 'manage_customizeDesign', 'manage_c
      ustomizeDesignForm',

  ### __authorPermissions__ Value:
      'manage', 'manage_main', 'manage_main_iframe', 'manage_workspace', 'ma
      nage_addZMSModule', 'manage_deleteObjs', 'manage_undoObjs', 'manage_mo
      veObjUp', 'manage_moveObjDown', 'manage_moveObjToPos', 'manage_cutObje
      cts', 'manage_copyObjects', 'manage_pasteObjs', 'manage_ajaxDragDrop',
       'manage_ajaxZMIActions', 'manage_properties', 'manage_changePropertie
      s', 'manage_changeTempBlobjProperty', 'manage_wfTransition', 'manage_w
      fTransitionFinalize', 'manage_userForm', 'manage_user', 'manage_import
      export', 'manage_import', 'manage_export', 'manage_executeMetacmd',

  ### __userAdministratorPermissions__ Value:
      'manage_users', 'manage_users_sitemap', 'manage_userProperties', 'mana
      ge_roleProperties', 'userdefined_roles',

  ### __ac_permissions__ Value:
      'ZMS Administrator', __administratorPermissions__, ('ZMS Author', __au
      thorPermissions__), ('ZMS UserAdministrator', __userAdministratorPermi
      ssions__),

  ### dGlobalAttrs Value:
      {'ZMS': {'obj_class': None}, 'ZMSCustom': {'obj_class': ZMSCustom}, 'Z
      MSLinkContainer': {}, 'ZMSLinkElement': {'obj_class': ZMSLinkElement},
       'ZMSSqlDb': {'obj_class': ZMSSqlDb, 'constructor': 'manage_addzmssqld
      bform'},}

  ### f_headDoctype Value:
      PageTemplateFile('zpt/ZMS/f_headdoctype', globals())

  ### f_headMeta_DC Value:
      PageTemplateFile('zpt/ZMS/f_headmeta_dc', globals())

  ### f_headMeta_Locale Value:
      PageTemplateFile('zpt/ZMS/f_headmeta_locale', globals())

  ### f_standard_html_header Value:
      PageTemplateFile('zpt/ZMS/f_standard_html_header', globals())

  ### f_standard_html_footer Value:
      PageTemplateFile('zpt/ZMS/f_standard_html_footer', globals())

  ### headCStyleSheet Value:
      PageTemplateFile('zpt/ZMS/headcstylesheet', globals())